@@ -1,10 +1,11 @@
+import re
 from re import sub
 import sklearn
 from sklearn.impute import SimpleImputer
 import pandas as pd
 from scipy import stats
 import numpy as np
-
+from AutoClean import AutoClean
 
 def remove_nan_values(**params):
     data = params['data']
@@ -134,4 +135,60 @@ def one_hot_encode(**params):
     return data_out
    
 
+def remove_mismatch_data(**params):
+    data = params['data']
+    exceptions = params['parameters']['exceptions']
+    for col in data : 
+        if col in exceptions : continue
+        data.reset_index(drop=True, inplace=True)
+        s = [False]*len(data[col])
+        for i,cell in enumerate(data[col]) : 
+            try : n = int(cell)
+            except : s[i] = True
+        t = s.count(True)
+        f = s.count(False)
+        st = False
+        if(t>f) : st = True
+        remove = [i for i in range(len(data[col])) if s[i]!=st]
+        data.drop(remove,axis=0,inplace=True)
+    return data
+
+def merge(**params):
+    data = params['data']
+    df = data.merge(**params['parameters'])
+    return df
+
+def rename_columns(**params):
+    data = params['data']
+    dict = params['dict']
+    axis = params['axis']
+    data = data.rename(dict, axis)
+    return data
+
+def select_column(**params):
+    data = params['data']
+    df = data.select_dtypes(**params['parameters'])
+    return df
+
+def clean_column_names(**params):
+    data = params['data']
+    match=r"[\]\[\,\{\}\"\:]+"
+    data.rename(columns=lambda x: re.sub(match, "", str(x)))
+    return data
+
+def clean_data(**params):
+    data = params['data']
+    df = AutoClean(data)
+    return df.output
+
+def clip(**params):
+    data = params['data']
+    data = data.clip(**params['paramters'])
+    return data
+
+def split_data(**params):
+    data = params['data']
+    df_shuffled = data.sample(frac=1)
+    df_splits = np.array_split(df_shuffled, 2)
+    return df_splits
 
